package rssbuffer

import (
	"html"
	"io"
	"time"

	"github.com/SlyMarbo/rss"
)

func BuildRSSDocument(out io.Writer, f *rss.Feed) {
	out.Write([]byte(`<?xml version="1.0" encoding="UTF-8"?>` + "\n"))

	out.Write([]byte(`<rss version="2.0" xmlns:atom="http://www.w3.org/2005/Atom" xmlns:content="http://purl.org/rss/1.0/modules/content/"><channel>`))
	{
		out.Write([]byte(`<title>` + html.EscapeString(f.Title) + `</title>`))
		out.Write([]byte(`<description>` + html.EscapeString(f.Title) + `</description>`))
		out.Write([]byte(`<link>` + html.EscapeString(f.Link) + "</link>\n"))

		for _, itm := range f.Items {
			out.Write([]byte(`<item>`))
			out.Write([]byte(`<title>` + html.EscapeString(itm.Title) + `</title>`))
			out.Write([]byte(`<link>` + html.EscapeString(itm.Link) + `</link>`))
			out.Write([]byte(`<guid>` + html.EscapeString(itm.ID) + `</guid>`))
			out.Write([]byte(`<pubDate>` + html.EscapeString(itm.Date.Format(time.RFC1123Z)) + `</pubDate>`))
			if len(itm.Content) > 0 && len(itm.Summary) > 0 {
				out.Write([]byte(`<description>` + html.EscapeString(itm.Summary) + `</description>`))
				out.Write([]byte(`<content:encoded>` + html.EscapeString(itm.Content) + `</content:encoded>`))

			} else if len(itm.Content) > 0 {
				out.Write([]byte(`<description>` + html.EscapeString(itm.Content) + `</description>`))

			} else if len(itm.Summary) > 0 {
				out.Write([]byte(`<description>` + html.EscapeString(itm.Summary) + `</description>`))

			} else {
				// ... neither Content nor Summary present
				out.Write([]byte(`<description></description>`))
			}

			out.Write([]byte("</item>\n"))
		}

	}

	out.Write([]byte(`</channel></rss>`))

}
