package main

import (
	"flag"
	"log"
	"os"

	"rssbuffer"
)

func main() {

	// Argument default values
	bindTo := "127.0.0.1:8123"
	flag.StringVar(&bindTo, "BindTo", bindTo, "Address/port to bind to")

	historyDays := 7
	flag.IntVar(&historyDays, "HistoryDays", historyDays, "Number of days' history to return in queries")

	backgroundRefreshMinutes := 30
	flag.IntVar(&backgroundRefreshMinutes, "BackgroundRefreshMinutes", backgroundRefreshMinutes, "Interval between refreshing known feeds")

	verboseLog := false
	flag.BoolVar(&verboseLog, "VerboseLog", verboseLog, "Verbose logging")

	flag.Parse()

	// Construct application
	app, err := rssbuffer.NewApplication(log.New(os.Stderr, "[rssbuffer] ", log.LstdFlags))
	if err != nil {
		os.Stderr.WriteString(err.Error() + "\n")
		os.Stderr.Sync()
		os.Exit(1)
	}

	// Pass parameters
	app.BindTo = bindTo
	app.RefreshMinutes = backgroundRefreshMinutes
	app.DaysOfHistory = historyDays
	app.VerboseLog = verboseLog

	// Launch
	app.Run()
}
